@@ -8,6 +8,7 @@ has msg_class    => "recv";
 has msg_from     => "none";
 has ttl          => 5;
 has allow_plugin => 1;
-has [qw(msg_id group_id sender_id receiver_id sender receiver group msg_time content raw_content)];
+has msg_time     => sub{time};
+has [qw(msg_id group_id sender_id receiver_id sender receiver group content raw_content)];
 
 1;
